/*
 *   Copyright (C) Christian Schulte, 2005-206
 *   All rights reserved.
 *
 *   Redistribution and use in source and binary forms, with or without
 *   modification, are permitted provided that the following conditions
 *   are met:
 *
 *     o Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *
 *     o Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in
 *       the documentation and/or other materials provided with the
 *       distribution.
 *
 *   THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *   INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 *   AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 *   THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 *   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 *   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *   $JOMC: NullEditor.java 4613 2012-09-22 10:07:08Z schulte $
 *
 */
package org.jomc.util.test.support;

import org.jomc.util.LineEditor;

/**
 * {@code LineEditor} removing all input.
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $JOMC: NullEditor.java 4613 2012-09-22 10:07:08Z schulte $
 *
 * @see #edit(java.lang.String)
 */
public final class NullEditor extends LineEditor
{

    /** Creates a new {@code NullEditor} instance. */
    public NullEditor()
    {
        this( null, null );
    }

    /**
     * Creates a new {@code NullEditor} instance taking a string to use for separating lines.
     *
     * @param lineSeparator String to use for separating lines.
     */
    public NullEditor( final String lineSeparator )
    {
        this( null, lineSeparator );
    }

    /**
     * Creates a new {@code NullEditor} instance taking an editor to chain.
     *
     * @param editor The editor to chain.
     */
    public NullEditor( final LineEditor editor )
    {
        this( editor, null );
    }

    /**
     * Creates a new {@code NullEditor} instance taking an editor to chain and a string to use for separating lines.
     *
     * @param editor The editor to chain.
     * @param lineSeparator String to use for separating lines.
     */
    public NullEditor( final LineEditor editor, final String lineSeparator )
    {
        super( editor, lineSeparator );
    }

    /**
     * {@inheritDoc}
     * @return This method returns {@code null}.
     */
    @Override
    protected String editLine( final String line )
    {
        return null;
    }

}
